[![CI](https://github.com/fhswf/MLPro-Int-OpenML/actions/workflows/ci.yml/badge.svg)](https://github.com/fhswf/MLPro-Int-OpenML/actions/workflows/ci.yml)
[![Documentation Status](https://readthedocs.org/projects/mlpro-int-openml/badge/?version=latest)](https://mlpro-int-openml.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/mlpro-int-openml.svg)](https://badge.fury.io/py/mlpro-int-openml)
<!---
[![Anaconda-Version Badge](https://anaconda.org/mlpro-int-openml/mlpro-int-openml/badges/version.svg)](https://anaconda.org/mlpro-int-openml/mlpro)
[![Anaconda-Downloads Badge](https://img.shields.io/conda/dn/mlpro-int-openml/mlpro-int-openml?color=green&label=Anaconda.org%20Total%20downloads&style=flat-square)](https://anaconda.org/mlpro-int-openml/mlpro-int-openml)
--->
[![PyPI Total Downloads](https://static.pepy.tech/personalized-badge/mlpro-int-openml?period=total&units=international_system&left_color=blue&right_color=orange&left_text=PyPI%20Total%20Downloads)](https://pepy.tech/project/mlpro-int-openml)
[![PyPI Last Month Downloads](https://static.pepy.tech/personalized-badge/mlpro-int-openml?period=month&units=international_system&left_color=blue&right_color=orange&left_text=PyPI%20Last%20Month%20Downloads)](https://pepy.tech/project/mlpro-int-openml)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.15206724.svg)](https://doi.org/10.5281/zenodo.15206724)


<img src="https://github.com/fhswf/MLPro-Int-OpenML/blob/main/doc/logo/original/logo.png?raw=True" align="right" width="40%"/>

# MLPro-Int-OpenML - Integration of OpenML into MLPro
Welcome to MLPro-Int-OpenML, an extension to MLPro to integrate the scientific data provider OpenML.
MLPro is a middleware framework for standardized machine learning in Python. It is 
developed by the South Westphalia University of Applied Sciences, Germany, and provides 
standards, templates, and processes for hybrid machine learning applications. OpenML, in turn, 
provides a vast amount of sample datasets, combined with a benchmark systematics to
enable a standardized assessment of ML algorithms.

MLPro-Int-OpenML provides wrapper classes that enable the use of OpenML datasets in your 
MLPro applications. The use of these wrappers is illustrated in example programs.

### Learn more
[MLPro - The integrative middleware framework for standardized machine learning in Python](https://mlpro.readthedocs.io)   
[MLPro-Int-OpenML - Integration of OpenML into MLPro](https://mlpro-int-openml.readthedocs.io)   
[OpenML - A worldwide machine learning lab](https://www.openml.org/)   
